@@ -3,14 +3,14 @@ Core API functions and initialization routines.
 """
 
 import configparser
+import logging
 import os
 import sys
-import logging
 import typing
 
 from . import backend, credentials
-from .util import platform_ as platform
 from .backends import fail
+from .util import platform_ as platform
 
 LimitCallable = typing.Callable[[backend.KeyringBackend], bool]
 
@@ -37,6 +37,13 @@ def get_keyring() -> backend.KeyringBackend:
 def disable() -> None:
     """
     Configure the null keyring as the default.
+
+    >>> fs = getfixture('fs')
+    >>> disable()
+    >>> disable()
+    Traceback (most recent call last):
+    ...
+    RuntimeError: Refusing to overwrite...
     """
     root = platform.config_root()
     try:
@@ -47,7 +54,7 @@ def disable() -> None:
     if os.path.exists(filename):
         msg = f"Refusing to overwrite {filename}"
         raise RuntimeError(msg)
-    with open(filename, 'w') as file:
+    with open(filename, 'w', encoding='utf-8') as file:
         file.write('[backend]\ndefault-keyring=keyring.backends.null.Keyring')
 
 
@@ -99,7 +106,7 @@ def _detect_backend(limit: typing.Optional[LimitCallable] = None):
         or load_config()
         or max(
             # all keyrings passing the limit filter
-            filter(limit, backend.get_all_keyring()),
+            filter(limit, backend.get_all_keyring()),  # type: ignore[arg-type] #659
             default=fail.Keyring(),
             key=backend.by_priority,
         )
@@ -134,7 +141,7 @@ def load_keyring(keyring_name: str) -> backend.KeyringBackend:
     """
     class_ = _load_keyring_class(keyring_name)
     # invoke the priority to ensure it is viable, or raise a RuntimeError
-    class_.priority
+    class_.priority  # noqa: B018
     return class_()
 
 
@@ -150,12 +157,18 @@ def _config_path():
     return platform.config_root() / 'keyringrc.cfg'
 
 
+def _ensure_path(path):
+    if not path.exists():
+        raise FileNotFoundError(path)
+    return path
+
+
 def load_config() -> typing.Optional[backend.KeyringBackend]:
     """Load a keyring using the config file in the config root."""
 
     config = configparser.RawConfigParser()
     try:
-        config.read(_config_path(), encoding='utf-8')
+        config.read(_ensure_path(_config_path()), encoding='utf-8')
     except FileNotFoundError:
         return None
     _load_keyring_path(config)
